@@ -32,5 +32,5 @@ The ellipses (`...`) are there to indicate that we may want to specify particula
 
 
 from .base import dispatch_funcs, mk_app
-from .util import run_streamlit, data_files
+from .util import run_streamlit
 from .data_binding import BoundData, binder
